@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 require File.expand_path("../helper", __FILE__)
 
-class TestRakeFileListPathMap < Rake::TestCase
+class TestRakeFileListPathMap < Rake::TestCase # :nodoc:
   def test_file_list_supports_pathmap
     assert_equal ["a", "b"], FileList["dir/a.rb", "dir/b.rb"].pathmap("%n")
   end
