@@ -169,4 +169,22 @@ class TestRakeTestTask < Rake::TestCase # :nodoc:
     task = Rake::Task[:child]
     assert_includes task.prerequisites, "parent"
   end
+
+  def test_task_order_only_prerequisites
+    t = task(a: 'b') {
+      :aaa
+    } | 'c'
+    b, c = task('b'), task('c')
+    assert_equal ['b'], t.prerequisites
+    assert_equal ['c'], t.order_only_prerequisites
+    assert_equal [b, c], t.prerequisite_tasks
+  end
+
+  def test_task_order_only_prerequisites_key
+    t = task 'a' => 'b', order_only: ['c']
+    b, c = task('b'), task('c')
+    assert_equal ['b'], t.prerequisites
+    assert_equal ['c'], t.order_only_prerequisites
+    assert_equal [b, c], t.prerequisite_tasks
+  end
 end
